//  COPYRIGHT:       PrimeObjects Software Inc. (C) 2022 All Right Reserved
//  COMPANY URL:     https://www.primeobjects.com/
//  CONTACT:         developer@primeobjects.com
//
//  This source is subject to the PrimeObjects License Agreements.
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __spreadArray = (this && this.__spreadArray) || function (to, from, pack) {
    if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
        if (ar || !(i in from)) {
            if (!ar) ar = Array.prototype.slice.call(from, 0, i);
            ar[i] = from[i];
        }
    }
    return to.concat(ar || Array.prototype.slice.call(from));
};
import React, { useEffect, useState, useRef } from "react";
import { cloneDeep, filter, find, throttle, debounce, map, isNil, isNumber } from "lodash";
import TableSection from "../table";
import { callApi } from "../../context/auth-call-api";
import { useCurrentContext } from "../../context/use-current-context";
import { SVG, getLocalStorage } from "primeobjects-ui-web-basic";
import { isNonEmptyString, getEntity, getCache, setCache, removeCache, numberWithCommas } from "primeobjects-helper-util";
import { DEFAULT_LIST_COLUMNS } from "./util";
import CSS from "primeobjects-ui-web-store/build/cjs/css";
import { getListTableCSS } from "./table-css";
import ListLoadingSection from "./loading";
import { usePrimaryColor, useSolution } from "primeobjects-helper-ui/build/cjs/index";
import { getApiEndpoint, getApiEndpointBase } from "../../util";
export var ListTableSection = function (props) {
    var _a, _b, _c, _d;
    var recordToUpdate = props.recordToUpdate, recordDeleted = props.recordDeleted, showTags = props.showTags, recordInAction = props.recordInAction, manualLoadMore = props.manualLoadMore, apis = props.apis, defaultRecordId = props.defaultRecordId, minWidth = props.minWidth, showScrollbarX = props.showScrollbarX;
    var solution = useSolution();
    var _e = useState(undefined), query = _e[0], setQuery = _e[1];
    var _f = useState(undefined), result = _f[0], setResult = _f[1];
    var _g = useState(true), loading = _g[0], setLoading = _g[1];
    var _h = useState(""), error = _h[0], setError = _h[1];
    var getColumns = props.getColumns
        ? props.getColumns
        : DEFAULT_LIST_COLUMNS;
    var primaryColor = usePrimaryColor();
    var data = result ? result.data : [];
    var entity = getEntity(solution, query === null || query === void 0 ? void 0 : query.entityName, query === null || query === void 0 ? void 0 : query.entityType);
    var entityName = entity === null || entity === void 0 ? void 0 : entity.entityName;
    var entityType = entity === null || entity === void 0 ? void 0 : entity.entityType;
    var tableId = "table-".concat(entityName).concat(entityType ? "-" + entityType : "");
    var wrapperClassName = (_a = props.wrapperClassName) !== null && _a !== void 0 ? _a : "";
    var wrapperStyle = (_b = props.wrapperStyle) !== null && _b !== void 0 ? _b : {};
    var tableWrapperClassName = (_c = props.tableWrapperClassName) !== null && _c !== void 0 ? _c : "";
    var tableWrapperStyle = (_d = props.tableWrapperStyle) !== null && _d !== void 0 ? _d : {};
    var tableSectionWrapper = useRef(null);
    var currentContext = useCurrentContext(solution, {
        componentName: "/pages/list-table.tsx"
    });
    var cacheKey = query &&
        isNumber(query.localCacheExpiredInSeconds) &&
        query.localCacheExpiredInSeconds >= 1 &&
        !isNonEmptyString(query.keywords) &&
        query.name == "first"
        ? "list-table-query-".concat(query.entityName, "-").concat(query.entityType, "-").concat(query.scope, "-").concat(query.keywords)
        : undefined;
    var abortController = useRef();
    useEffect(function () {
        if (recordToUpdate && result) {
            if (find(result.data, function (r) {
                return r.id == recordToUpdate.id;
            })) {
                setResult(__assign(__assign({}, result), { data: map(result.data, function (r) {
                        return r.id == recordToUpdate.id ? recordToUpdate : r;
                    }) }));
            }
            else {
                setResult(__assign(__assign({}, result), { data: __spreadArray([cloneDeep(recordToUpdate)], result.data, true) }));
            }
            cacheKey && removeCache(cacheKey);
        }
    }, [JSON.stringify(recordToUpdate)]);
    useEffect(function () {
        if (recordDeleted && result) {
            setResult({
                count: result.count - 1,
                data: filter(result.data, function (r) { return r.id != recordDeleted.id; })
            });
            cacheKey && removeCache(cacheKey);
        }
    }, [JSON.stringify(recordDeleted)]);
    useEffect(function () {
        setResult(undefined);
        setQuery(props.query);
    }, [props.query]);
    useEffect(function () {
        if (!isNil(props.refresh) && isNonEmptyString("".concat(props.refresh))) {
            setQuery(__assign(__assign({}, props.query), { name: "refresh" }));
        }
    }, [props.refresh]);
    var onLoadError = function (query, error) {
        if ((error === null || error === void 0 ? void 0 : error.message) != "canceled") {
            console.error(error);
            setError("Sorry, failed to load ".concat(entity === null || entity === void 0 ? void 0 : entity.uiCollectionName, "."));
            props.onLoadFailed && props.onLoadFailed(query, error);
            setLoading(false);
            abortController.current = null;
        }
    };
    var onLoadSuccess = function (query, result, cacheKey) {
        setResult(result);
        setLoading(false);
        abortController.current = null;
        if (cacheKey) {
            setCache(cacheKey, {
                query: query,
                result: result
            }, query.localCacheExpiredInSeconds);
        }
        props.onLoadSuccess && props.onLoadSuccess(query, result);
    };
    useEffect(function () {
        var _a;
        if (query) {
            if (query.name != "more")
                setResult(undefined);
            (_a = abortController.current) === null || _a === void 0 ? void 0 : _a.abort();
            abortController.current = new AbortController();
            setLoading(true);
            setError("");
            var apiEndpoint = apis
                ? getApiEndpointBase(apis, "data", "query")
                : getApiEndpoint(solution, "data", "query", entity === null || entity === void 0 ? void 0 : entity.entityName);
            if (isNonEmptyString(query.keywords)) {
                query.keywords = query.keywords
                    .trim()
                    .replace(new RegExp("( ){2,}", "g"), " ");
                var localQueryService = getLocalStorage("query-service-".concat(query.entityName));
                query.service =
                    query.service != "hidden"
                        ? localQueryService
                            ? localQueryService
                            : query.service
                                ? query.service
                                : "auto"
                        : "auto";
                if (query.service == "auto") {
                    query.service =
                        query.keywords.split(" ").length > 1
                            ? "elastic"
                            : "database";
                }
                apiEndpoint = apis
                    ? getApiEndpointBase(apis, "data", "search")
                    : getApiEndpoint(solution, "data", "search", entity === null || entity === void 0 ? void 0 : entity.entityName);
            }
            if (cacheKey) {
                var cacheResult = getCache(cacheKey);
                if (cacheResult &&
                    JSON.stringify(cacheResult.query) == JSON.stringify(query)) {
                    return onLoadSuccess(query, cacheResult.result);
                }
            }
            apiEndpoint &&
                callApi(solution, apiEndpoint, 
                // "http://localhost:3000/prod/query",
                defaultRecordId
                    ? {
                        query: query,
                        id: defaultRecordId,
                        entityName: query.entityName
                    }
                    : { query: query }, "post", {
                    abortSignal: abortController.current.signal
                })
                    .then(function (r) {
                    var newResult = { count: 0, data: [] };
                    switch (query.name) {
                        case "more": {
                            newResult = {
                                count: (result === null || result === void 0 ? void 0 : result.count) + r.count,
                                continuation: r.continuation,
                                data: __spreadArray(__spreadArray([], (result ? result.data : {}), true), r.data, true)
                            };
                            break;
                        }
                        default: {
                            newResult = r;
                            break;
                        }
                    }
                    if (props.onLoadPostProcess) {
                        props
                            .onLoadPostProcess(query, newResult)
                            .then(function (postResult) {
                            onLoadSuccess(query, postResult, cacheKey);
                        })
                            .catch(function (error) {
                            onLoadError(query, error);
                            abortController.current = null;
                        });
                    }
                    else {
                        onLoadSuccess(query, newResult, cacheKey);
                    }
                })
                    .catch(function (error) {
                    onLoadError(query, error);
                    abortController.current = null;
                });
        }
    }, [query]);
    var onClickFooterLoadMore = function () {
        if (tableSectionWrapper.current &&
            !isNil(tableSectionWrapper.current.scrollTop)) {
            tableSectionWrapper.current.scrollTop =
                tableSectionWrapper.current.scrollHeight;
        }
    };
    var onLoadMore = debounce(function () {
        query &&
            setQuery(__assign(__assign({}, query), { name: "more", pageNumber: query.pageNumber + 1 }));
    }, 200);
    var onScrollList = function (e) {
        //console.log({ a: Math.abs(e.target.scrollHeight - e.target.scrollTop - e.target.clientHeight), b: result?.continuation, c: loading });
        if (Math.abs(e.target.scrollHeight -
            e.target.scrollTop -
            e.target.clientHeight) < 15 &&
            !isNil(result === null || result === void 0 ? void 0 : result.continuation) &&
            !isNonEmptyString(loading) &&
            manualLoadMore != true) {
            onLoadMore();
        }
    };
    var renderLoadingMore = function () {
        return ((result === null || result === void 0 ? void 0 : result.continuation) && (React.createElement("div", { className: "w-full flex justify-center py-5" },
            React.createElement("div", { className: "flex flex-col items-center justify-center" }, (query === null || query === void 0 ? void 0 : query.name) == "more" ? (React.createElement(SVG, { src: "/icons/platform/loading.svg", className: "spinner", style: { width: 30, height: 30 } })) : (React.createElement(SVG, { src: "/icons/platform/down.svg", className: "cursor-pointer", style: { width: 30, height: 30 }, onClick: onLoadMore }))))));
    };
    var renderEmpty = function () {
        if (data.length > 0 || loading)
            return null;
        return props.renderEmpty && props.renderEmpty();
    };
    var renderError = function () {
        if (!isNonEmptyString(error))
            return null;
        return (React.createElement("div", { className: "w-full text-base p-4 flex flex-col text-red-600" }, error));
    };
    var renderLoading = function () {
        if (!loading || (query && query.name == "more"))
            return null;
        return (React.createElement(ListLoadingSection, { id: "list-table-loading", height: 60, count: 3, barHeight: 10, widthAdj: -30 }));
    };
    var onRowSelected = function (newSelectedIds, newSelectedRecords) {
        if (props.onRowSelected)
            props.onRowSelected(newSelectedIds, newSelectedRecords);
    };
    var onClickRecord = function (record, action, entity, rowIndex) {
        switch (action) {
            case "read": {
                props.onReadRecord &&
                    props.onReadRecord(record, action, entity, rowIndex);
                break;
            }
            case "delete": {
                props.onDeleteRecord &&
                    props.onDeleteRecord(record, action, entity, rowIndex);
                break;
            }
            case "clone": {
                props.onCloneRecord &&
                    props.onCloneRecord(record, action, entity, rowIndex);
                break;
            }
            case "create": {
                props.onCreateRecord &&
                    props.onCreateRecord(record, action, entity, rowIndex);
                break;
            }
            case "edit": {
                props.onEditRecord &&
                    props.onEditRecord(record, action, entity, rowIndex);
                break;
            }
            case "nothing": {
                return;
            }
        }
        props.onClickRecord &&
            props.onClickRecord(record, action, entity, rowIndex);
    };
    var onClickTag = function (tag) {
        props.onClickTag && props.onClickTag(tag);
    };
    var onApplyConditions = function (conditions) {
        props.onApplyConditions && props.onApplyConditions(conditions);
    };
    var columns = getColumns(onClickRecord, entity, {
        showTags: showTags,
        onClickTag: onClickTag,
        recordInAction: recordInAction,
        onApplyConditions: onApplyConditions,
        context: currentContext
    });
    var hideHeader = filter(columns, function (c) { return isNonEmptyString(c.title); }).length == 0;
    var tableWrapperHeightAdj = (props.showInfoHeader ? 2 : 0) + (props.showInfoFooter ? 2 : 0);
    var renderInfoHeader = function () {
        if (props.infoHeader)
            return props.infoHeader;
        return (React.createElement(React.Fragment, null,
            props.infoHeaderContent,
            React.createElement("span", { className: "text-xs leading-none" },
                "Count: ",
                numberWithCommas(data.length))));
    };
    var renderInfoFooter = function () {
        if (props.infoFooter)
            return props.infoFooter;
        return (React.createElement(React.Fragment, null,
            props.infoFooterContent,
            (result === null || result === void 0 ? void 0 : result.continuation) && (React.createElement("span", { className: "text-xs cursor-pointer", onClick: onClickFooterLoadMore }, "More ..."))));
    };
    return (React.createElement("div", { className: "list-table-wrapper w-full h-full ".concat(wrapperClassName), style: wrapperStyle },
        props.showInfoHeader && (React.createElement("div", { className: "w-full h-8 py-2 px-4 flex flex-col items-end", style: {
                borderBottom: "1px solid #f0f0f0"
            } }, renderInfoHeader())),
        React.createElement("div", { className: "list-table w-full flex ".concat(hideHeader ? "hide-header" : "", " ").concat(tableWrapperClassName), style: __assign(__assign({}, tableWrapperStyle), { height: "calc(100% - ".concat(tableWrapperHeightAdj, "rem)") }) },
            React.createElement("div", { ref: tableSectionWrapper, className: "overflow-hidden overflow-y-auto w-full", onScroll: throttle(onScrollList, 500) },
                React.createElement(CSS, { id: "list-table-css", content: "\n                        ".concat(getListTableCSS(primaryColor["600"]), "\n                        ").concat(showScrollbarX
                        ? ""
                        : ".list-table .ant-table-body::-webkit-scrollbar\n                            {\n                                width: 0px;\n                            }\n                            ", "\n                        ") }),
                data.length > 0 && (React.createElement(TableSection, { scrollbarX: showScrollbarX, id: tableId, selectionType: props.selectionType, onRowSelected: onRowSelected, columns: columns, data: data, minWidth: minWidth })),
                renderLoading(),
                renderError(),
                renderEmpty(),
                renderLoadingMore())),
        props.showInfoFooter && (React.createElement("div", { className: "w-full h-8 py-2 px-4 flex flex-col items-end" }, renderInfoFooter()))));
};
export default ListTableSection;
//# sourceMappingURL=table.js.map