//  COPYRIGHT:       PrimeObjects Software Inc. (C) 2022 All Right Reserved
//  COMPANY URL:     https://www.primeobjects.com/
//  CONTACT:         developer@primeobjects.com
//
//  This source is subject to the PrimeObjects License Agreements.
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import React, { useEffect, useState } from "react";
import { isNonEmptyString, isSSR } from "primeobjects-helper-util/build/cjs/core";
import SectionTitle from "./site-title";
import { callApiBase, getApiEndpoint } from "../util";
import { getRecordAbstract } from "primeobjects-helper-util/build/cjs/record";
import { isNumber, map, uniqBy, without } from "lodash";
import { getPrimaryColor } from "primeobjects-helper-ui";
import Lottie from "primeobjects-ui-web-basic/build/cjs/controls/lottie";
import { COLORS } from "primeobjects-helper-util";
import { convertHtmlToText } from "primeobjects-ui-web-basic/build/cjs/util/other";
export var SiteSimilarSection = function (props) {
    var solution = props.solution, feedValue = props.feedValue, feedType = props.feedType, title = props.title, subTitle = props.subTitle, titleSize = props.titleSize, subTitleSize = props.subTitleSize, pageNumber = props.pageNumber, urlTemplate = props.urlTemplate, globalOrganizationId = props.globalOrganizationId, scope = props.scope, flushCache = props.flushCache;
    var _a = useState(true), loading = _a[0], setLoading = _a[1];
    var _b = useState(null), result = _b[0], setResult = _b[1];
    var SSR = isSSR();
    var wrapperClassName = isNonEmptyString(props.wrapperClassName)
        ? props.wrapperClassName
        : "";
    var listClassName = isNonEmptyString(props.listClassName)
        ? props.listClassName
        : "";
    var itemTitleClassName = isNonEmptyString(props.itemTitleClassName)
        ? props.itemTitleClassName
        : "";
    var entityName = props.entityName ? props.entityName : "Card";
    var pageSize = isNumber(props.pageSize) && props.pageSize > 0 ? props.pageSize : 5;
    var _c = useState([]), data = _c[0], setData = _c[1];
    var primaryColor = getPrimaryColor(solution);
    var fullRecord = false;
    var cacheKey = props.cacheKey
        ? "".concat(props.cacheKey, "-").concat(feedType, "-").concat(feedValue, "-").concat(scope, "-").concat(fullRecord)
        : undefined;
    useEffect(function () {
        var newData = (result === null || result === void 0 ? void 0 : result.data) ? result === null || result === void 0 ? void 0 : result.data : [];
        var additionalData = props.additionalData ? props.additionalData : [];
        for (var i = 0; i < additionalData.length && newData.length < 5; i++) {
            newData.push(additionalData[i]);
        }
        setData(uniqBy(newData, function (d) { return d.id; }));
        setLoading(false);
    }, [result, props.additionalData]);
    useEffect(function () {
        if (solution.id && !SSR) {
            callApiBase(getApiEndpoint(solution, "recommendation", "similar-by-content"), __assign(__assign({}, (feedType == "id"
                ? {
                    id: feedValue
                }
                : {
                    content: feedValue
                })), { fullRecord: fullRecord, scope: scope, globalOrganizationId: globalOrganizationId, entityName: entityName, pageSize: pageSize, pageNumber: pageNumber, cacheKey: cacheKey, flushCache: flushCache, cacheExpireMinutes: 60 * 24 * 365 }), "POST", { solutionId: solution.id }).then(function (result) {
                setResult(result);
            });
        }
    }, [SSR, solution.id]);
    return (React.createElement("div", { className: "w-full ".concat(wrapperClassName) },
        React.createElement(SectionTitle, { title: title, subTitle: subTitle, titleSize: titleSize, subTitleSize: subTitleSize, titleClassName: "text-left text-".concat(primaryColor.name, "-600"), subTitleClassName: "text-left" }),
        loading ? (React.createElement(React.Fragment, null,
            React.createElement("div", { className: "w-full flex flex-row items-center" },
                React.createElement("div", { className: "h-10" },
                    React.createElement(Lottie, { className: "w-full h-full", url: "/icons/platform/lottie/dots-2.json", colors: Array(6).fill(COLORS.GRAY[600]) })),
                React.createElement("div", { className: "flex-1 text-base text-gray-600 p-2" }, "Loading ...")))) : (React.createElement("div", { className: "flex flex-col pt-2 ".concat(listClassName) }, without(map(data, function (record, i) {
            var title = record.title
                ? record.title
                : record.display;
            record.abstract = convertHtmlToText(record.abstract, "abstract");
            var desc = getRecordAbstract(record, 128, true);
            return record.stateCode < 0 ? null : (React.createElement("div", { className: "py-2", key: i },
                React.createElement("a", { href: urlTemplate
                        .replace(/\[PH.SLUG\]/g, record.slug)
                        .replace(/\[PH.ID\]/g, record.id), className: "flex flex-col mb-5 text-gray-900 ".concat(itemTitleClassName), style: {
                        textDecoration: "none"
                    } },
                    React.createElement("span", { className: "font-semibold text-lg line-clamp-3 ".concat(isNonEmptyString(desc)
                            ? "mb-3"
                            : "mb-0") }, title),
                    React.createElement("p", { className: "text-base text-gray-500 line-clamp-3", style: { paddingBottom: 0 } }, desc))));
        }), null)))));
};
export default SiteSimilarSection;
//# sourceMappingURL=site-similar.js.map