//  COPYRIGHT:       PrimeObjects Software Inc. (C) 2022 All Right Reserved
//  COMPANY URL:     https://www.primeobjects.com/
//  CONTACT:         developer@primeobjects.com
//
//  This source is subject to the PrimeObjects License Agreements.
import React, { useEffect, useState } from "react";
import { isNonEmptyString, isSSR } from "primeobjects-helper-util/build/cjs/core";
import SiteTitle from "./site-title";
import { callApiBase } from "../util";
import { getRecordAbstract } from "primeobjects-helper-util/build/cjs/record";
import { slug } from "primeobjects-helper-util/build/cjs/slug";
import { getPrimaryColor } from "primeobjects-helper-ui";
import { isNil, isNumber, map } from "lodash";
import { getApiEndpoint } from "../util";
import { getRecordDisplay, newGuid } from "primeobjects-helper-util";
import ContentLoaderSection from "primeobjects-ui-web-basic/build/cjs/controls/content-loader";
import { useRouter } from "next/navigation";
import { getGlobalComponent } from "../util";
var SwiperComponent = undefined;
var SwiperPagination = undefined;
var SwiperSlide = undefined;
export var SiteSwiperSection = function (props) {
    var solution = props.solution, feedValue = props.feedValue, feedType = props.feedType, title = props.title, subTitle = props.subTitle, titleSize = props.titleSize, subTitleSize = props.subTitleSize, pageNumber = props.pageNumber, urlTemplate = props.urlTemplate, globalOrganizationId = props.globalOrganizationId, scope = props.scope, flushCache = props.flushCache;
    if (!SwiperComponent) {
        console.log("Get global components in /sections/site-swiper.tsx");
        SwiperComponent = getGlobalComponent("SwiperComponent");
        SwiperPagination = getGlobalComponent("SwiperPagination");
        SwiperSlide = getGlobalComponent("SwiperSlide");
    }
    var router = useRouter();
    var _a = useState(null), result = _a[0], setResult = _a[1];
    var SSR = isSSR();
    var wrapperClassName = isNonEmptyString(props.wrapperClassName)
        ? props.wrapperClassName
        : "";
    var itemTitleClassName = isNonEmptyString(props.itemTitleClassName)
        ? props.itemTitleClassName
        : "";
    var entityName = props.entityName ? props.entityName : "Card";
    var pageSize = isNumber(props.pageSize) && props.pageSize > 0 ? props.pageSize : 5;
    var data = (result === null || result === void 0 ? void 0 : result.data) ? result === null || result === void 0 ? void 0 : result.data : [];
    var primaryColor = getPrimaryColor(solution);
    var id = slug("".concat(title, "-").concat(feedValue, "-").concat(feedType));
    var cacheKey = props.cacheKey
        ? "".concat(props.cacheKey, "-").concat(feedType, "-").concat(feedValue, "-").concat(scope)
        : undefined;
    var getQuery = function () {
        switch (feedType) {
            case "tags":
                return {
                    scope: scope,
                    entityName: entityName,
                    pageSize: pageSize,
                    pageNumber: pageNumber,
                    tags: feedValue.split(","),
                    globalOrganizationId: globalOrganizationId,
                    conditions: [
                        { attribute: "stateCode", op: ">=", value: 0 }
                    ],
                    attributes: "slug,id,media,title,name,abstract,summary"
                };
            case "categories":
                return {
                    scope: scope,
                    entityName: entityName,
                    pageSize: pageSize,
                    pageNumber: pageNumber,
                    categoryIds: feedValue.split(","),
                    globalOrganizationId: globalOrganizationId,
                    conditions: [
                        { attribute: "stateCode", op: ">=", value: 0 }
                    ],
                    attributes: "slug,id,media,title,name,abstract,summary"
                };
        }
    };
    useEffect(function () {
        if (solution.id && !SSR) {
            var apiUrl = getApiEndpoint(solution, "data", "query");
            callApiBase(apiUrl, {
                query: getQuery(),
                cacheKey: cacheKey,
                flushCache: flushCache,
                cacheExpireMinutes: 60 * 24 * 365
            }, "POST", { solutionId: solution.id })
                .then(function (result) {
                setResult(result);
            })
                .catch(function () {
                setResult({ count: 0, data: [] });
            });
        }
    }, [solution.id, SSR]);
    return isNil(result) || (!isNil(result) && data.length > 0) ? (React.createElement("div", { className: "w-full ".concat(wrapperClassName) },
        React.createElement(SiteTitle, { title: title, subTitle: subTitle, titleSize: titleSize, subTitleSize: subTitleSize, titleClassName: "text-left text-".concat(primaryColor.name, "-600"), subTitleClassName: "text-left" }),
        React.createElement("div", { className: "w-full" }, isNil(result) ? (React.createElement("div", { className: "w-full h-full mb-16" },
            React.createElement(ContentLoaderSection, { id: id ? id : newGuid(), height: 100, count: 5, width: 400, barHeight: 10 }))) : (React.createElement(SwiperComponent, { slidesPerView: 1, spaceBetween: 10, pagination: {
                clickable: true
            }, breakpoints: {
                640: {
                    slidesPerView: Math.min(data.length, 2),
                    spaceBetween: Math.min(data.length, 2) * 10
                },
                768: {
                    slidesPerView: Math.min(data.length, 3),
                    spaceBetween: Math.min(data.length, 3) * 10
                },
                1024: {
                    slidesPerView: Math.min(data.length, 4),
                    spaceBetween: Math.min(data.length, 4) * 10
                }
            }, modules: [SwiperPagination] }, map(data, function (record, i) {
            var desc = getRecordAbstract(record, 128, true);
            var media = record.media;
            var url = urlTemplate
                .replace(/\[PH.SLUG\]/g, record.slug)
                .replace(/\[PH.ID\]/g, record.id);
            return (React.createElement(SwiperSlide, { key: i },
                React.createElement("div", { className: "w-full h-full mb-16" },
                    React.createElement("div", { onClick: function () {
                            router.push(url);
                        }, className: "flex flex-col cursor-pointer mb-5 ".concat(itemTitleClassName) },
                        isNonEmptyString(media) && (React.createElement("div", { className: "w-full bg-center bg-cover mb-6", style: {
                                backgroundImage: "url(".concat(media, ")"),
                                height: 0,
                                paddingTop: "66%"
                            } })),
                        React.createElement("div", { className: "font-semibold text-lg ".concat(isNonEmptyString(desc)
                                ? "mb-3"
                                : "mb-0") }, getRecordDisplay(record)),
                        React.createElement("div", { className: "text-gray-500" }, desc)))));
        })))))) : (React.createElement(React.Fragment, null));
};
export default SiteSwiperSection;
//# sourceMappingURL=site-swiper.js.map